@@ -5,7 +5,7 @@ if __name__ == "__main__":
     if len(l)<1:print(Colours().colour(17,"Enter -h or --help to get more info\nEnter -c or --colours to list colours and Responsible number"))
     
     try:
-        opts, args = getopt.getopt(l,"ch")
+        opts, args = getopt.getopt(l,"ch",['help','colours'])
     except getopt.GetoptError:
         print(Colours().colour(17,"Enter -h or --help to get more info\nEnter -c or --colours to list colours and Responsible number"))
         sys.exit(2)
@@ -23,7 +23,7 @@ Options:
 \nUsage(2):-\n
 ---------------
 first import ,
-    {Colours().colour(170,"From Colour import Colours")}
+    {Colours().colour(170,"From Niram import Colours")}
 change colour,
     {Colours().colour(170,"Colours().colour(<colour code(will get in '-c')>,Your text,second=your second colour or background)")}
     
